/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figure 3: 	Trends in aging and robot adoption across
			developed countries
			
Notes: 		
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/3/2021
			
Output: 	/results/figure_trends_aging.pdf

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_robot_density=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_robot_density i.dreg
keep if e(sample)==1


* robot density over time *
forvalues year=1993(1)2014{
gen robot_density`year'=stock_robots_`year'/$normalization_robots
}

* keep relevant variables *
keep robot_density* ${aging_measure}* country_name new_region

***Full sample***
preserve
reshape long robot_density ${aging_measure}, i(country_name) j(year)
collapse (mean) robot_density* ${aging_measure}*, by(year)
rename robot_density robot_density_all 
rename ${aging_measure} depe_all 
tempfile all
save `all', replace
restore

***OECD sample***
preserve
keep if new_region=="OECD"
reshape long robot_density ${aging_measure}, i(country_name) j(year)
collapse (mean) robot_density* ${aging_measure}*, by(year)
rename robot_density robot_density_oecd 
rename ${aging_measure} depe_oecd 
tempfile oecd
save `oecd', replace
restore

***US***
preserve
keep if country_name=="united states"
reshape long robot_density ${aging_measure}, i(country_name) j(year)
rename robot_density robot_density_us
rename ${aging_measure} depe_us 
tempfile us
save `us', replace
restore

***GERMANY***
preserve
keep if country_name=="germany"
reshape long robot_density ${aging_measure}, i(country_name) j(year)
rename robot_density robot_density_deu 
rename ${aging_measure} depe_deu 
tempfile germany
save `germany', replace
restore

***KOREA***
preserve
keep if country_name=="south korea"
reshape long robot_density ${aging_measure}, i(country_name) j(year)
rename robot_density robot_density_kor 
rename ${aging_measure} depe_kor 
tempfile korea
save `korea', replace
restore

***Merge and plot***
use `all', clear
merge 1:1 year using `oecd', assert(3) nogenerate
merge 1:1 year using `us', assert(3) nogenerate
merge 1:1 year using `germany', assert(3) nogenerate
merge 1:1 year using `korea', assert(3) nogenerate

tsset year

**********************************************
********Left Panel of Figure 3****************
**********************************************
keep if year>=1970 & year<=2025
twoway (connected depe_all year, mcolor(blue%80) msymbol(square) mfcolor(blue%30) mlcolor(black) lcolor(black)) ///
       (connected depe_oecd year, mcolor(red%50) msymbol(triangle) mlcolor(black) lcolor(black)) ///
       (connected depe_us year, mcolor(gold%50) msymbol(circle) mlcolor(black) lcolor(black)) ///
       (connected depe_deu year, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)) ///
	   (connected depe_kor year, lcolor(black) msymbol(lgx)), ///
	   ylabel(, noticks angle(horizontal)) xlabel(1970(10)2025) xtitle(" ") title("Ratio of older to middle-aged workers", position(11)) ///
	   graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))  ///
	   legend(on pos(11) ring(0) order(1 "All countries" 2 "OECD countries" 3 "United States" 4 "Germany" 5 "South Korea") rows(3) cols(2) region(lcolor(none))) xsize(6) ysize(4) ///
	   name(aging, replace)

**********************************************
********Right Panel of Figure 3***************
**********************************************
keep if year<=2015 & year>1992
twoway (connected robot_density_all year, mcolor(blue%80) msymbol(square) mfcolor(blue%30) mlcolor(black) lcolor(black)) ///
       (connected robot_density_oecd year, mcolor(red%50) msymbol(triangle) mlcolor(black) lcolor(black)) ///
       (connected robot_density_us year, mcolor(gold%50) msymbol(circle) mlcolor(black) lcolor(black)) ///
       (connected robot_density_deu year, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)) ///
	   (connected robot_density_kor year, lcolor(black) msymbol(lgx)), ///
	   ylabel(, noticks angle(horizontal)) xlabel(1995(5)2015) xtitle(" ") title("Robots per thousand industry workers", position(11)) ///
	   graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))  ///
	   legend(off) xsize(6) ysize(4) ///
	   name(robot_density, replace)

gr combine aging robot_density, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) xsize(8) cols(2) 
graph export "$project/results/figure_trends_aging.pdf", as(pdf) replace
	
