/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figure A1: 	Industry characteristics
			
Notes: 		

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/3/2021
			
Output: 	/results/industry_characteristics.pdf

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

* determine sample of countries in Table 1 *
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg if country_name!= "japan" & country_name!="russian federation"
gen full_sample=e(sample)

* keep relevant covariates *
keep isocode full_sample ${aging_measure}* ${instruments} $industry_covariates dreg* ${normalization_robots}

* expand dataset *
expand 19
gen industry_ifr=""
bys isocode: replace industry_ifr="agriculture" if _n==1
bys isocode: replace industry_ifr="automotive" if _n==2
bys isocode: replace industry_ifr="construction" if _n==3
bys isocode: replace industry_ifr="education" if _n==4
bys isocode: replace industry_ifr="electronics" if _n==5
bys isocode: replace industry_ifr="food" if _n==6
bys isocode: replace industry_ifr="furniture" if _n==7
bys isocode: replace industry_ifr="glass" if _n==8
bys isocode: replace industry_ifr="man_other" if _n==9
bys isocode: replace industry_ifr="metal_basic" if _n==10
bys isocode: replace industry_ifr="metal_machinery" if _n==11
bys isocode: replace industry_ifr="metal_products" if _n==12
bys isocode: replace industry_ifr="mining" if _n==13
bys isocode: replace industry_ifr="nman_other" if _n==14
bys isocode: replace industry_ifr="paper" if _n==15
bys isocode: replace industry_ifr="plastic_chemicals" if _n==16
bys isocode: replace industry_ifr="textiles" if _n==17
bys isocode: replace industry_ifr="utilities" if _n==18
bys isocode: replace industry_ifr="vehicles_other" if _n==19
expand 23
bys isocode industry_ifr: gen year=_n+1992 

* robotics variables by industry * country * year *
merge 1:1 isocode industry_ifr year using "${project}/clean_data/country_industry_robot_flows.dta", assert(1 3) nogenerate

* klems and UNIDO variables by industry * country * year *
merge m:1 isocode industry_ifr using "${project}/clean_data/country_industry_klems.dta", assert(1 3) nogenerate
merge m:1 isocode industry_ifr using "${project}/clean_data/country_industry_unido.dta", assert(1 3) nogenerate

* merge industry characteristics *
merge m:1 industry_ifr using "${project}/clean_data/replaceability_ifr19.dta", assert(3) nogenerate
merge m:1 industry_ifr using "${project}/clean_data/uscensus_industry_1990", nogenerate
merge m:1 industry_ifr using "${project}/clean_data/uscensus_industry_2000", nogenerate
gen routine_bcg=0
replace routine_bcg=1 if industry_ifr=="automotive"
replace routine_bcg=1 if industry_ifr=="electronics"
replace routine_bcg=1 if industry_ifr=="metal_machinery"
replace routine_bcg=1 if industry_ifr=="plastic_chemicals"

gen indname=""
replace indname="Agriculture" if industry_ifr=="agriculture"
replace indname="Automotive" if industry_ifr=="automotive"
replace indname="Plastics, Pharma and Chemicals" if industry_ifr=="plastic_chemicals"
replace indname="Construction" if industry_ifr=="construction"
replace indname="R&D" if industry_ifr=="education"
replace indname="Electronics" if industry_ifr=="electronics"
replace indname="Food and Beverages" if industry_ifr=="food"
replace indname="Wood and Furniture" if industry_ifr=="furniture"
replace indname="Glass and Ceramics" if industry_ifr=="glass"
replace indname="Miscellaneous" if industry_ifr=="man_other"
replace indname="Basic Metals" if industry_ifr=="metal_basic"
replace indname="Industrial Machinery" if industry_ifr=="metal_machinery"
replace indname="Metal Products " if industry_ifr=="metal_products"
replace indname="Mining" if industry_ifr=="mining"
replace indname="Services" if industry_ifr=="nman_other"
replace indname="Paper and Printing" if industry_ifr=="paper"
replace indname="Textiles" if industry_ifr=="textiles"
replace indname="Utilities" if industry_ifr=="utilities"
replace indname="Shipbuilding and Aerospace" if industry_ifr=="vehicles_other"

gen ratio_young=(1-share_55_emp_1990)/share_55_emp_1990
gen flow=investment_robots/(klems_employees_1995)
collapse (mean) replaceable ratio_young flow, by(indname)
twoway (scatter replaceable ratio_young [w=flow], mcolor(dkorange)) (scatter replaceable ratio_young, mlabangle(forty_five) mlabpos(8) mlabel(indname) mlabcolor(gs6) mlabsize(vsmall) msize(0)), ///
       legend(off) ylabel(0(0.1)0.45, angle(horizontal)) xtitle("Middle-aged to older worker ratio (US Census, 1990)") ytitle(Share of replaceable occupations in industry) ///
       graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))  plotregion(lcolor(black)) ysize(5) xsize(6)
graph export "$project/results/industry_characteristics.pdf", as(pdf)  replace
