/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figures A3 
and A4: 	Robustness comtrade
			
Notes: 		1. Full sample is for Figure A3, and
			OECD sample is for Figure A4.
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/3/2021
			
Output: 	/results/comtrade_robustness_full.pdf
			/results/comtrade_robustness_oecd.pdf

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* order in which commodities will appear in the figure *
local order_commodities subpanelA industrial_robot numerically_controlled machine_tools  automatic_welding weaving_textile dedicated_textile transfer_equipment control_instruments subpanelB capital_goods dedicated_food   manual_tools  not_numerically_controlled  manual_machtool  manual_welding  transfer_tools  subpanelC  laundry_machine vending_machine  agriculture_machine  computers 

* program to remove outliers *
cap program drop reg_outliers
program define reg_outliers, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	tempvar residual
	tempvar cons_sample
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	predict `residual' if e(sample)==1, resid
	quietly: sum `residual'
	gen `cons_sample'=(`residual'>-1.96*r(sd) & `residual'<1.96*r(sd)) if e(sample)==1
	reg `y_vars' `x_var' `controls'  `wt'  if `cons_sample'==1, r
end

* loop over sample (oecd, full)*type of flow (imports exports)
foreach  sample in full oecd{
foreach flowtable in im ex {

* create dataset to save estimation results *
preserve
clear
set obs 30
gen category=""
gen spec1_b=.
gen spec1_se=.
gen spec2_b=.
gen spec2_se=.
gen spec3_b=.
gen spec3_se=.
gen spec4_b=.
gen spec4_se=.
gen flow="`flowtable'"
save "$project/temp_data/estimates_`flowtable'ports.dta", replace
restore

	**************************
	*******Housekeeping*******
	**************************


* covariates *
use "$project/clean_data/country_covariates.dta", clear

* comtrade imports of intermediates *
merge 1:1 isocode using "${project}/clean_data/comtrade_1990_2015.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*compute total imports of intermediate goods*
foreach flow in im_ ex_ re_{
egen intermediate_`flow'90=rowtotal(tv_`flow'agriculture_machine tv_`flow'automatic_welding tv_`flow'capital_goods tv_`flow'computers tv_`flow'control_instruments tv_`flow'dedicated_food tv_`flow'dedicated_textile tv_`flow'industrial_robot tv_`flow'laundry_machine tv_`flow'machine_tools tv_`flow'manual_machtool tv_`flow'manual_tools tv_`flow'manual_welding tv_`flow'none tv_`flow'not_numerically_controlled tv_`flow'numerically_controlled tv_`flow'transfer_equipment tv_`flow'transfer_tools tv_`flow'vending_machine tv_`flow'weaving_textile), missing
}
gen ln_imports=ln(intermediate_im_90)
  
*sample selection*
if "`flowtable'"=="im"{
drop if country_name=="japan" | country_name=="luxembourg" 
local wvar $imports_weights
}
else if "`flowtable'"=="ex"{
drop if country_name=="nigeria"
local wvar $exports_weights
}
if "`sample'"=="oecd"{
keep if new_region=="OECD"
}

*aging variables
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*regions*
encode new_region, gen(dreg)

**Loop over commodities**
local i=1
foreach cat of local  order_commodities {


if "`cat'"=="subpanelA" | "`cat'"=="subpanelB" | "`cat'"=="subpanelC" {
preserve
use  "$project/temp_data/estimates_`flowtable'ports.dta", clear
replace category="ph" in `i'
local i=`i'+1
replace category="`cat'" in `i'
save "$project/temp_data/estimates_`flowtable'ports.dta", replace
restore
}
else{ 
*remove re-exports*
gen nim_`cat'=tv_im_`cat'-tv_re_`cat'
gen nex_`cat'=tv_ex_`cat'

gen share_`cat'=n`flowtable'_`cat'/intermediate_`flowtable'_90 if n`flowtable'_`cat'>=0

**Specification 1: baseline*
gen lns_`cat'=ln(share_`cat')
reg lns_`cat'  change_dependency  $country_covariates_1990 i.dreg `wvar', r
local beta=_b[change_dependency]
local serr=_se[change_dependency]

preserve
use "$project/temp_data/estimates_`flowtable'ports.dta", clear
replace category="`cat'" in `i'
replace spec1_b=`beta' in `i'
replace spec1_se=`serr' in `i'
save "$project/temp_data/estimates_`flowtable'ports.dta", replace
restore

**Specification 2: log(1+share) or Poisson*
gen ln1_`cat'=ln(1000000*share_`cat'+1)
ivreg2 ln1_`cat'  (change_dependency=$instruments)   $country_covariates_1990 i.dreg `wvar', r
local beta=_b[change_dependency]
local serr=_se[change_dependency]

preserve
use "$project/temp_data/estimates_`flowtable'ports.dta", clear
replace spec2_b=`beta' in `i'
replace spec2_se=`serr' in `i'
save "$project/temp_data/estimates_`flowtable'ports.dta", replace
restore

**Specification 3: share *
gen sh_`cat'=share_`cat' 
ivreg2 sh_`cat'  (change_dependency=$instruments)  $country_covariates_1990 i.dreg `wvar', r
sum sh_`cat' if e(sample) `wvar'
local beta=_b[change_dependency]/r(mean)
local serr=_se[change_dependency]/r(mean)

preserve
use "$project/temp_data/estimates_`flowtable'ports.dta", clear
replace spec3_b=`beta' in `i'
replace spec3_se=`serr' in `i'
save "$project/temp_data/estimates_`flowtable'ports.dta", replace
restore

**Specification 4: remove outliers*
gen lno_`cat'=ln(1000000*share_`cat')

reg_outliers lno_`cat' change_dependency `wvar', controls($country_covariates_1990 i.dreg)
local beta=_b[change_dependency]
local serr=_se[change_dependency]

preserve
use "$project/temp_data/estimates_`flowtable'ports.dta", clear
replace spec4_b=`beta' in `i'
replace spec4_se=`serr' in `i'
replace flow="`flowtable'" in `i'
save "$project/temp_data/estimates_`flowtable'ports.dta", replace
restore
}

local i=`i'+1
}
}

use "$project/temp_data/estimates_imports.dta", clear
drop if cat==""
gen base_num=_n
expand 5
sort base_num
gen number=126-_n
save "$project/temp_data/estimates_imports.dta", replace

use "$project/temp_data/estimates_exports.dta", clear
drop if cat==""
gen base_num=_n
expand 5
sort base_num
gen number=126-_n
save "$project/temp_data/estimates_exports.dta", replace

use "$project/temp_data/estimates_imports.dta", clear
append using "$project/temp_data/estimates_exports.dta"

replace flow="A. Imports" if flow=="im"
replace flow="B. Exports" if flow=="ex"

*label panels*
replace category="..." if category=="ph"
replace category="Group 1: industrial automation" if category=="subpanelA" 
replace category="Group 2: other capital goods" if category=="subpanelB"
replace category="Group 3: not industrial" if category=="subpanelC"


*label categories*
replace category="Dedicated machinery (inc. robots)" if category=="industrial_robot" /*Dedicated machinery (in HS robots also reported here)*/
replace category="Numerically controlled machines" if category=="numerically_controlled" /*Numerically controlled machines*/ 
replace category="Automatic welding machines" if category=="automatic_welding" /*Automatic welding machines*/
replace category="Weaving and knitting machines" if category=="weaving_textile" /*Spinning, weaving and knitting machines used in textiles*/ 
replace category="Other textile dedicated machinery" if category=="dedicated_textile" /*Dedicated machinery used in textiles*/
replace category="Automatic machine tools" if category=="machine_tools" /**/  
replace category="Regulating and control instruments" if category=="control_instruments" /**/  
replace category="Automatic conveyors" if category=="transfer_equipment" /**/ 

replace category="Tools for industrial work" if category=="manual_tools" /*Tools (includes only those with industrial uses)*/
replace category="Manual machine tools" if category=="manual_machtool" /**/ 
replace category="Manual welding machines" if category=="manual_welding" /**/ 
replace category="Not-numerically controlled vintages" if category=="not_numerically_controlled" /*Machines that are not numerically controlled, but that variants of them are numerically controlled*/  
replace category="Tools for transferring materials" if category=="transfer_tools" /**/ 
replace category="Heavy capital goods" if category=="capital_goods" /*Other industrial machinery not classified (excluding computers and electronic parts)*/ 
replace category="Food manufacturing" if category=="dedicated_food" /*Baking and Brewing equipment for industrial use*/

replace category="Laundry machines" if category=="laundry_machine" /*Laundry machines*/
replace category="Vending machines" if category=="vending_machine" /*Vending machines*/
replace category="Agricultural machinery" if category=="agriculture_machine" /*Machines used in agricultural production*/
replace category="Computers" if category=="computers" /*Computers*/


replace category=" " if number!=5*floor(number/5)+4

gen estimator_1=1 if number==5*floor(number/5)+4
gen estimator_2=1 if number==5*floor(number/5)+3
gen estimator_3=1 if number==5*floor(number/5)+2
gen estimator_4=1 if number==5*floor(number/5)+1

drop if number>119

labmask number, values(category)

forvalues j=1(1)4{
gen spec`j'_low =spec`j'_b-1.65*spec`j'_se
gen spec`j'_high=spec`j'_b+1.65*spec`j'_se

*Truncating things so that they fit into the full figure*
replace spec`j'_low =.  if spec`j'_low<-2  & flow=="A. Imports"
replace spec`j'_high =. if spec`j'_high>4  & flow=="A. Imports"

replace spec`j'_low =.  if spec`j'_low<-7  & flow=="B. Exports"
replace spec`j'_high =. if spec`j'_high>10 & flow=="B. Exports"

}

* plot figure *
twoway 	(bar     spec1_b number if estimator_1==1, sort fcolor(white) fintensity(0) lcolor(black) lwidth(vthin) horizontal barwidth(0.8)) ///
		(rcap    spec1_low spec1_high number if estimator_1==1, sort lcolor(gs2) lwidth(vvthin) horizontal msize(vsmall)) ///
		(bar     spec2_b number if estimator_2==1, sort fcolor(dkorange) fintensity(30) lcolor(black) lwidth(vthin) horizontal barwidth(0.8)) ///
		(rcap    spec2_low spec2_high number if estimator_2==1, sort lcolor(gs2) lwidth(vvthin) horizontal msize(vsmall)) ///
		(bar     spec3_b number if estimator_3==1, sort fcolor(cranberry) fintensity(60) lcolor(black) lwidth(vthin) horizontal barwidth(0.8)) ///
		(rcap    spec3_low spec3_high number if estimator_3==1, sort lcolor(gs2) lwidth(vvthin) horizontal msize(vsmall)) ///
		(bar     spec4_b number if estimator_4==1, sort fcolor(dkorange) fintensity(100) lcolor(black) lwidth(vthin) horizontal barwidth(0.8)) ///
		(rcap    spec4_low spec4_high number if estimator_4==1, sort lcolor(gs2) lwidth(vvthin) horizontal msize(vsmall)), ///
		legend(symysize(*.3) symxsize(*.6) rows(4) order(1 "baseline (OLS)" 3 "log one plus share" 5 "share" 7 "exclude outliers") region(lcolor(none)) bmargin(zero) size(vsmall) ) ysize(8) xsize(14) ytitle("") yscale(noline) /// 
		ylabel(4(5)119, labels labsize(small) angle(horizontal) valuelabel noticks grid glpattern(solid) glcolor(gs12) glwidth(vvthin) nogextend) ///
		xtitle("")  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(lcolor(white) lwidth(vthin)) xline(0, lcolor(black) lwidth(vthin)) ///
		by(flow, note("") noiytick xrescale legend(on position(4))  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(lcolor(white) lwidth(vthin))) subtitle(, margin(medium) nobox)
graph export "$project/results/comtrade_robustness_`sample'.pdf", as(pdf)  replace
}
