/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figure A6: 	Validation comtrade data on robot imports vs IFR 
			
Notes: 		
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/4/2021
			
Output: 	/results/figure_validate_comtrade_level.pdf
			/results/figure_validate_comtrade_log.pdf
						

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

***Program that defines the plot-style ***
cap program drop resid_plot
program define resid_plot, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string) name(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	reg `y_vars' `x_var' `controls'  `wt'  `if', r
	local beta: di %3.2f  _b[`x_var']
	local tstat: di %3.2f _b[`x_var']/_se[`x_var']
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	
	
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=0
	
	*Residuals*
	quietly: egen `tag_rank'=rank(`residual_y') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<5 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`residual_y') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<5 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Yvar*
	quietly: egen `tag_rank'=rank(`y_vars') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<3 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`y_vars') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<4 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Xvar*
	quietly: egen `tag_rank'=rank(`x_var') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<3 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`x_var') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<4 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: replace `tag_label'=1 if country_name=="united states"
	quietly: replace `tag_label'=1 if country_name=="finland"
	
	
	tempvar labvar
	gen `labvar'=upper(country_name)
	
	twoway (scatter `projected_y' `x_var' `wt' if `projected_y'!=.,  color(dkorange) msize(*1)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., lcolor(navy) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mlabel(`labvar') mlabpos(12) mlabcolor(navy) msize(*0)), ///
		   ylabel(, noticks angle(horizontal)) legend(off) xtitle("`xtitle'", size(large)) ytitle("") title("`ytitle'", position(11)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(4) xsize(7) name("`name'", replace)
   
end


* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

*imports of robots *
merge 1:1 isocode using "${project}/clean_data/comtrade_robots_1996_2015.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

* robot imports per thousand industry workers *
gen change_robots=(stock_robots_2014-stock_robots_1993)/$normalization_robots
gen imports_robots=tv_im_robots_orig/$normalization_robots
gen ln_change_robots=ln((stock_robots_2014-stock_robots_1993)/$normalization_robots)
gen ln_imports_robots=ln(tv_im_robots_orig/$normalization_robots)

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates  
gen full_sample=e(sample)

* numbers mentioned on footnote XX. Note: import data missing for Taiwan *
reg imports_robots change_robots if full_sample==1
reg imports_robots change_robots if full_sample==1 & country_name!="germany" & country_name!="south korea"
reg imports_robots change_robots if full_sample==1 & country_name!="belgium" & country_name!="singapore"

* plots *
**********************************************
********Top Panel of Figure A6****************
**********************************************
resid_plot imports_robots change_robots if full_sample==1, xtitle("Increase in robots per thousand workers (IFR)") ytitle("Value of robot imports per thousand workers")
graph export "$project/results/figure_validate_comtrade_level.pdf", as(pdf)  replace

**********************************************
********Bottom Panel of Figure A6*************
**********************************************
resid_plot ln_imports_robots ln_change_robots if full_sample==1, xtitle("(log) Increase in robots per thousand workers (IFR)") ytitle("(log) Value of robot imports per thousand workers")
graph export "$project/results/figure_validate_comtrade_log.pdf", as(pdf)  replace

