/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A17: 	Robustness analysis of the impact of aging on
			robotics-related patents
			
Notes: 		

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_patents_robustness_full.tex
			/results/table_patents_robustness_oecd.tex
			/results/table_patents_robustness_oecd_nous.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* programs to drop outliers *
cap program drop reg_outliers
program define reg_outliers, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	tempvar residual
	tempvar cons_sample
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	predict `residual' if e(sample)==1, resid
	quietly: sum `residual'
	gen `cons_sample'=(`residual'>-1.96*r(sd) & `residual'<1.96*r(sd)) if e(sample)==1
	reg `y_vars' `x_var' `controls'  `wt'  if `cons_sample'==1, r
end

cap program drop ivreg_outliers
program define ivreg_outliers, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	tempvar residual
	tempvar cons_sample
	
	quietly: ivreg2 `y_vars' (`x_var'=$instruments) `controls'  `wt'  `if', r
	predict `residual' if e(sample)==1, resid
	quietly: sum `residual'
	gen `cons_sample'=(`residual'>-1.96*r(sd) & `residual'<1.96*r(sd)) if e(sample)==1
	ivreg2 `y_vars' (`x_var'=$instruments) `controls'  `wt'  if `cons_sample'==1, r
end


foreach sample in full oecd oecd_nous{

	**************************
	*******Housekeeping*******
	**************************

* covariates *	
use "$project/clean_data/country_covariates.dta", clear

* patent data---drop others category *
merge 1:1 isocode using "${project}/clean_data/country_patents.dta", keep(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg)

*log of patents*
gen ln_patents=ln(t_utility_patents)

*aging variables
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

if "`sample'"=="oecd"{
keep if new_region=="OECD"
}
else if "`sample'"=="oecd_nous"{
keep if new_region=="OECD" & isocode!="USA"
}

	************************
	*******Estimation*******
	************************ 

***FULL SAMPLE***
*Baseline weighted*
gen share_ln=ln(automation_rel)
reg share_ln  change_dependency ln_manuf_va ln_patents  $country_covariates_1990   i.dreg  $patent_weights, r
estimates store e1 

ivreg2 share_ln  (change_dependency=$instruments) ln_manuf_va ln_patents  $country_covariates_1990   i.dreg  $patent_weights, r
estimates store e2 

*log(1+x)*
gen share_full=ln(1000*automation_rel+1)
reg share_full  change_dependency ln_manuf_va ln_patents  $country_covariates_1990   i.dreg  $patent_weights, r
estimates store e3 

ivreg2 share_full  (change_dependency=$instruments ) ln_manuf_va ln_patents  $country_covariates_1990   i.dreg  $patent_weights, r
estimates store e4

*Share*
sum automation_rel 
gen share_base=automation_rel/r(mean)
reg share_base  change_dependency ln_manuf_va ln_patents  $country_covariates_1990   i.dreg  $patent_weights, r
estimates store e5 

ivreg2 share_base  (change_dependency=$instruments ) ln_manuf_va ln_patents  $country_covariates_1990   i.dreg  $patent_weights, r
estimates store e6

*Remove outliers*
reg_outliers   share_ln  change_dependency $patent_weights,  control(ln_manuf_va ln_patents  $country_covariates_1990   i.dreg)
estimates store e7 

ivreg_outliers   share_ln  change_dependency $patent_weights,  control(ln_manuf_va ln_patents  $country_covariates_1990   i.dreg)
estimates store e8 

estout e1 e2 e3 e4 e5 e6 e7 e8 using "$project/results/table_patents_robustness_`sample'.tex", style(tex) ///
varlabels(change_dependency "Aging between 1990 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2 widstat jp, fmt(%7.0f %7.2f %7.1f %7.2f) labels("Observations" "R-squared"  "First-stage $ F$  stat." "Overid p-value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep( change_dependency ) ///
order(change_dependency ) 

}

