/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A2: 	Summary statistics for industries

Notes: 		1. Do-file does not currently generate any output. 
			This table is cardcoded in the Latex file.

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	...			
			...

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	***********************************************************
	*******Housekeeping: prepare robot flows by industry*******
	***********************************************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

* determine sample of countries in Table 1 *
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg if country_name!= "japan" & country_name!="russian federation"
gen full_sample=e(sample)

* keep relevant covariates *
keep isocode full_sample ${aging_measure}* ${instruments} $industry_covariates dreg* ${normalization_robots}

* expand dataset *
expand 19
gen industry_ifr=""
bys isocode: replace industry_ifr="agriculture" if _n==1
bys isocode: replace industry_ifr="automotive" if _n==2
bys isocode: replace industry_ifr="construction" if _n==3
bys isocode: replace industry_ifr="education" if _n==4
bys isocode: replace industry_ifr="electronics" if _n==5
bys isocode: replace industry_ifr="food" if _n==6
bys isocode: replace industry_ifr="furniture" if _n==7
bys isocode: replace industry_ifr="glass" if _n==8
bys isocode: replace industry_ifr="man_other" if _n==9
bys isocode: replace industry_ifr="metal_basic" if _n==10
bys isocode: replace industry_ifr="metal_machinery" if _n==11
bys isocode: replace industry_ifr="metal_products" if _n==12
bys isocode: replace industry_ifr="mining" if _n==13
bys isocode: replace industry_ifr="nman_other" if _n==14
bys isocode: replace industry_ifr="paper" if _n==15
bys isocode: replace industry_ifr="plastic_chemicals" if _n==16
bys isocode: replace industry_ifr="textiles" if _n==17
bys isocode: replace industry_ifr="utilities" if _n==18
bys isocode: replace industry_ifr="vehicles_other" if _n==19
expand 23
bys isocode industry_ifr: gen year=_n+1992 

* robotics variables by industry * country * year *
merge 1:1 isocode industry_ifr year using "${project}/clean_data/country_industry_robot_flows.dta", assert(1 3) nogenerate


* klems and UNIDO variables by industry * country * year *
merge m:1 isocode industry_ifr using "${project}/clean_data/country_industry_klems.dta", assert(1 3) nogenerate
merge m:1 isocode industry_ifr using "${project}/clean_data/country_industry_unido.dta", assert(1 3) nogenerate

* normalizations *
gen emp_base=${normalization_robots}/19
gen emp_klems=klems_employees_1995
gen emp_unido=unido_employees/1000 
replace emp_unido=unido_num_engaged*0.8/1000 if emp_unido==. /*use 90% of persosns engaged for countries with missing empoyment data, including Germany */

* normalized by thousand of workers *
gen flows_base=investment_robots/emp_base
gen flows_klems=investment_robots/emp_klems
gen flows_unido=investment_robots/emp_unido

* number of countries covered *
unique country_name if flows_base!=.
unique country_name if flows_klems!=.
unique country_name if flows_unido!=.

* sample selection: Countries for which we observe some robot data and are in our baseline sample *
gen sample_all=(1-tag_noobs_flow)*tag_classified_flow*full_sample 
keep if sample_all==1

collapse (mean) flows_base flows_klems flows_unido, by(industry) 
tempfile robots
save `robots', replace


	***********************************************************
	*******Housekeeping: prepare aggregates by industry *******
	***********************************************************

use "${project}/clean_data/country_industry_klems.dta", clear

* sample selection *
drop if isocode== "JPN" 

* construct change in value added and labor share *
gen change_vadded=ln(klems_labprod_2007)-ln(klems_labprod_1995)
replace change_vadded=(ln(klems_labprod_2006)-ln(klems_labprod_1995))*12/11 if  change_vadded==.
replace change_vadded=(ln(klems_labprod_2005)-ln(klems_labprod_1995))*12/10 if  change_vadded==.

gen change_labsh=klems_labsh_2007-klems_labsh_1995
replace change_labsh=(klems_labsh_2006-klems_labsh_1995)*12/11 if  change_labsh==.
replace change_labsh=(klems_labsh_2005-klems_labsh_1995)*12/10 if  change_labsh==.

* collapse at industry level *
collapse (mean) change_vadded change_labsh (rawsum) klems_employees_1995, by(industry)
egen total_emp=total(klems_employees_1995)
gen share_emp=klems_employees_1995/total_emp
tempfile aggregates
save `aggregates', replace

	***********************************************************
	*******Housekeeping: clean industry characteristics *******
	***********************************************************

use "${project}/clean_data/replaceability_ifr19.dta", clear
merge 1:1 industry_ifr using "${project}/clean_data/uscensus_industry_1990", nogenerate
merge 1:1 industry_ifr using "${project}/clean_data/uscensus_industry_2000", nogenerate
gen routine_bcg=0
replace routine_bcg=1 if industry_ifr=="automotive"
replace routine_bcg=1 if industry_ifr=="electronics"
replace routine_bcg=1 if industry_ifr=="metal_machinery"
replace routine_bcg=1 if industry_ifr=="plastic_chemicals"

gen young_intensity=(1-share_55_emp_1990)/share_55_emp_1990
gen routine_intensity_rep=replaceable  
gen routine_intensity_bcg=routine_bcg

	***********************************************************
	*******Merge and present summary stats by industry  *******
	***********************************************************

merge 1:1 industry_ifr using `robots', nogenerate assert(3)
merge 1:1 industry_ifr using `aggregates', nogenerate assert(3)

gen manuf=(flows_unido!=. | industry=="man_other")
gsort -routine_intensity_bcg -flows_unido 

gen indname=""
replace indname="Agriculture" if industry_ifr=="agriculture"
replace indname="Automotive" if industry_ifr=="automotive"
replace indname="Plastics, Pharma and Chemicals" if industry_ifr=="plastic_chemicals"
replace indname="Construction" if industry_ifr=="construction"
replace indname="R&D" if industry_ifr=="education"
replace indname="Electronics" if industry_ifr=="electronics"
replace indname="Food and Beveradges" if industry_ifr=="food"
replace indname="Wood and Furniture" if industry_ifr=="furniture"
replace indname="Glass and Ceramics" if industry_ifr=="glass"
replace indname="Miscellaneous" if industry_ifr=="man_other"
replace indname="Basic Metals" if industry_ifr=="metal_basic"
replace indname="Industrial Machinery" if industry_ifr=="metal_machinery"
replace indname="Metal Products " if industry_ifr=="metal_products"
replace indname="Mining" if industry_ifr=="mining"
replace indname="Services" if industry_ifr=="nman_other"
replace indname="Paper and Printing" if industry_ifr=="paper"
replace indname="Textiles" if industry_ifr=="textiles"
replace indname="Utilities" if industry_ifr=="utilities"
replace indname="Shipbuilding and Aerospace" if industry_ifr=="vehicles_other"

bro indname flows_base flows_klems flows_unido change_vadded change_labsh young_intensity routine_intensity_rep routine_intensity_bcg share_emp
