/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A3: 	Estimates of the impact of aging on the adoption of
			industrial robots using different definitions of
			middle-aged and older workers

Notes: 		1. This do-file generates unused tex files
			marked below.

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_cutoff_55_y.tex (unused)
			/results/table_cutoff_60_y.tex
			/results/table_cutoff_50_y.tex
			/results/table_cutoff_65conc55_y.tex
			/results/table_cutoff_70conc55_y.tex
			/results/table_cutoff_75conc55_y.tex
			/results/table_cutoff_mid55_y.tex 

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************
	
	* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************   

********************************************************************************************************	
************************Loop over definitions of aging used in different panels (A-F) ******************
********************************************************************************************************
foreach var in 55_y 60_y 50_y 65conc55_y 70conc55_y 75conc55_y mid55_y{

cap drop change_dependency
gen change_dependency=(dependency_`var'2025-dependency_`var'1990)

***Full sample***
reg change_robots 	change_dependency i.dreg $country_covariates_min dependency_`var'1990 if full_sample, r
estimates store e1

ivreg2 change_robots (change_dependency=$instruments ) i.dreg $country_covariates_min dependency_`var'1990 if full_sample, r partial(i.dreg $country_covariates_min dependency_`var'1990) ffirst
estimates store e3

***OECD sample***
reg change_robots 	change_dependency $country_covariates_min dependency_`var'1990 if new_region=="OECD", r
estimates store e2

ivreg2 change_robots (change_dependency=$instruments )  $country_covariates_min dependency_`var'1990 if new_region=="OECD", r partial($country_covariates_min dependency_`var'1990 ) ffirst
estimates store e4

*Export tables*
estout e1 e2 e3 e4 using  "$project/results/table_cutoff_`var'.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )


}

