/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A14: 	Cross-sectional estimates of relationship between
			the ratio of older to middle-aged workers and
			the stock of industrial robots
			
Notes: 		1. Because this table only exploits cross sectional
			variation, Japan is included in Sample

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_levels_ols.tex
			/results/table_levels_ols_weighted.tex
			/results/table_levels_iv.tex
			/results/table_levels_iv_weighted.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************
	
* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen robot_density_2014=(stock_robots_2014/$normalization_robots)

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*sample selection (the levels for Japan should be ok)*
keep if country_name!="russian federation" 
quietly: reg robot_density_2014 log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 ln_manuf_va   i.dreg
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************   

*****************************************************************************************	
*****************Table A14, Panel A: OLS models, unweighted *****************************
*****************************************************************************************

reg robot_density_2014 	${aging_measure}2025 i.dreg if full_sample, r
estimates store e1

reg robot_density_2014 	${aging_measure}2025 i.dreg log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 if full_sample, r
estimates store e2

reg robot_density_2014 	${aging_measure}2025 ln_manuf_va   i.dreg log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 if full_sample, r
estimates store e3

reg robot_density_2014 	${aging_measure}2025 if new_region=="OECD", r
estimates store e4

reg robot_density_2014 	${aging_measure}2025 log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014  if new_region=="OECD", r
estimates store e5

reg robot_density_2014 	${aging_measure}2025 ln_manuf_va   log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 if new_region=="OECD", r
estimates store e6


*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_levels_ols.tex", style(tex) ///
varlabels(${aging_measure}2025     "Older to middle-age ratio in 2025" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(${aging_measure}2025   ) ///
order(${aging_measure}2025 )


*****************************************************************************************	
*****************Table A14, Panel C: OLS models, weighted *******************************
*****************************************************************************************

reg robot_density_2014 	${aging_measure}2025 i.dreg if full_sample  $robot_weight, r
estimates store e1

reg robot_density_2014 	${aging_measure}2025 i.dreg log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 if full_sample  $robot_weight, r
estimates store e2

reg robot_density_2014 	${aging_measure}2025 ln_manuf_va   i.dreg log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 if full_sample  $robot_weight, r
estimates store e3

reg robot_density_2014 	${aging_measure}2025 if new_region=="OECD"  $robot_weight, r
estimates store e4

reg robot_density_2014 	${aging_measure}2025 log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014  if new_region=="OECD"  $robot_weight, r
estimates store e5

reg robot_density_2014 	${aging_measure}2025 ln_manuf_va   log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014  if new_region=="OECD"  $robot_weight, r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_levels_ols_weighted.tex", style(tex) ///
varlabels(${aging_measure}2025     "Older to middle-age ratio in 2025" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(${aging_measure}2025 ) ///
order(${aging_measure}2025)


*****************************************************************************************	
*****************Table A14, Panel B: IV models, unweighted ******************************
*****************************************************************************************

ivreg2 robot_density_2014 	(${aging_measure}2025=$instruments ) i.dreg if full_sample, r  partial(i.dreg) ffirst
estimates store e1

ivreg2 robot_density_2014 	(${aging_measure}2025=$instruments ) i.dreg log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 if full_sample, r  partial(i.dreg) ffirst
estimates store e2

ivreg2 robot_density_2014 	(${aging_measure}2025=$instruments ) ln_manuf_va   i.dreg log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 if full_sample, r  partial(i.dreg) ffirst
estimates store e3

ivreg2 robot_density_2014 	(${aging_measure}2025=$instruments ) if new_region=="OECD", r   ffirst
estimates store e4

ivreg2 robot_density_2014 	(${aging_measure}2025=$instruments ) log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 if new_region=="OECD", r   ffirst
estimates store e5

ivreg2 robot_density_2014 	(${aging_measure}2025=$instruments ) ln_manuf_va  log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 if new_region=="OECD", r   ffirst
estimates store e6


*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_levels_iv.tex", style(tex) ///
varlabels(${aging_measure}2025     "Older to middle-age ratio in 2025" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(${aging_measure}2025) ///
order(${aging_measure}2025)


*****************************************************************************************	
*****************Table A14, Panel D: IV models, weighted ********************************
*****************************************************************************************

ivreg2 robot_density_2014 	(${aging_measure}2025=$instruments ) i.dreg if full_sample $robot_weight, r  partial(i.dreg) ffirst
estimates store e1

ivreg2 robot_density_2014 	(${aging_measure}2025=$instruments ) i.dreg log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 if full_sample $robot_weight, r  partial(i.dreg) ffirst
estimates store e2

ivreg2 robot_density_2014 	(${aging_measure}2025=$instruments ) ln_manuf_va   i.dreg log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 if full_sample $robot_weight, r  partial(i.dreg) ffirst
estimates store e3

ivreg2 robot_density_2014 	(${aging_measure}2025=$instruments ) if new_region=="OECD" $robot_weight, r   ffirst
estimates store e4

ivreg2 robot_density_2014 	(${aging_measure}2025=$instruments ) log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 if new_region=="OECD" $robot_weight, r   ffirst
estimates store e5

ivreg2 robot_density_2014 	(${aging_measure}2025=$instruments ) ln_manuf_va   log_pwt_output_capita2014 log_pwt_population2014 pwt_human_capital2014 if new_region=="OECD" $robot_weight, r   ffirst
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_levels_iv_weighted.tex", style(tex) ///
varlabels(${aging_measure}2025     "Older to middle-age ratio in 2025") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(${aging_measure}2025) ///
order(${aging_measure}2025)



